@@ -5,7 +5,7 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
- * © 2013 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
+ * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author David Bauer <david.bauer@open-xchange.com>
  * @author Julian Bäume <julian.baeume@open-xchange.com>
@@ -21,4 +21,6 @@ module.exports = function (grunt) {
     grunt.registerTask('build', ['copy_build', 'less']);
     // create a package ready version of the ui (aka what jenkins does)
     grunt.registerTask('dist', ['clean', 'checkDependencies:build', 'bower', 'build', 'copy_dist']);
+    //remove install:dynamic task (make it a noop)
+    grunt.registerTask('install:dynamic', []);
 };
